TransportClose

Struct TransportClose 

pub struct TransportClose {
    pub code: Option<u16>,
    pub reason: String,
    pub was_clean: bool,
}
Details reported when a transport connection closes.

Fields

code: Option<u16>

WebSocket close code, if a close frame was received.

reason: String

Human-readable close reason.

was_clean: bool

Whether the transport considered the close handshake clean.

Implementations

Source

impl TransportClose

pub fn new( code: Option<u16>, reason: impl Into<String>, was_clean: bool, ) -> Self

Creates close details reported by a transport.

pub fn connection_ended() -> Self

Creates an abnormal close for a stream that ended without a close frame.

pub fn should_reconnect(&self) -> bool

Returns whether the managed client should reconnect this close by default.